@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -440,7 +437,6 @@ calculateTimeRemaining(void)
 {
     int		cnt;
     float		deltaAvg[2];
-    float       avg_sum;
 
     if (!((_flags[0] & 0x4) == 4)) {
         _charge[0] = 0;
@@ -456,6 +452,10 @@ calculateTimeRemaining(void)
     _batteryHistory[0][_historyCount] = _batLevel[0] - _charge[0];
     _batteryHistory[1][_historyCount] = _batLevel[1] - _charge[1];
     
+    //If these are both zero, discount them!
+    if (!_batteryHistory[0][_historyCount] && !_batteryHistory[1][_historyCount] ) {
+        return;
+    } 
     //Reset the delta values
     deltaAvg[0] = deltaAvg[1] = 0;
 
@@ -509,14 +509,9 @@ calculateTimeRemaining(void)
             deltaAvg[1] = 0;
         }
     
-        avg_sum = ((double)deltaAvg[0]+(double)deltaAvg[1]);
-        if(avg_sum != 0.0)
-        {
-            _hoursRemaining[0] = -1*((double)toCharge[0])/avg_sum/360;
-            _hoursRemaining[1] = -1*((double)toCharge[1])/avg_sum/360;        
-        } else {
-            _hoursRemaining[0] = _hoursRemaining[1] = -1.0;        
-        }
+        //_hoursRemaining[0] = -1*((((double)toCharge[0]+(double)toCharge[1]))/((double)deltaAvg[0]+(double)deltaAvg[1]))/360;
+        _hoursRemaining[0] = -1*(((double)toCharge[0])/((double)deltaAvg[0]+(double)deltaAvg[1]))/360;
+        _hoursRemaining[1] = -1*(((double)toCharge[1])/((double)deltaAvg[0]+(double)deltaAvg[1]))/360;        
     } else if (!isBatteryPresent(0) && !isBatteryPresent(1)) {
         //When there are no batteries installed
         //if there were batteries installed before hand, then reset the history (so we get
@@ -542,14 +537,9 @@ calculateTimeRemaining(void)
         
         _state = 2;
             
-        avg_sum = ((double)deltaAvg[0]+(double)deltaAvg[1]);
-        if(avg_sum != 0.0)
-        {
-            _hoursRemaining[0] = ((double)_charge[0])/avg_sum/360;
-            _hoursRemaining[1] = ((double)_charge[1])/avg_sum/360;
-        } else {
-            _hoursRemaining[0] = _hoursRemaining[1] = -1.0;        
-        }
+        //_hoursRemaining[0] = ((((double)_charge[0]+(double)_charge[1]))/((double)deltaAvg[0]+(double)deltaAvg[1]))/360;     
+        _hoursRemaining[0] = (((double)_charge[0])/((double)deltaAvg[0]+(double)deltaAvg[1]))/360;
+        _hoursRemaining[1] = (((double)_charge[1])/((double)deltaAvg[0]+(double)deltaAvg[1]))/360;
     }
     
     _batLevel[0]   = _charge[0];
